@@ -92,6 +92,7 @@ opts_chunk = new_defaults(list(
 #' @rdname opts_chunk
 #' @export
 opts_current = new_defaults()
+opts_current$restore(opts_chunk$get())
 
 #' @include plot.R
 
@@ -115,6 +116,7 @@ opts_chunk_attr = local({
   opts$external = opts$sanitize = NULL  # hide these two rare options
   opts$fig.process = 'function'
   opts$fig.asp = 'numeric'
+  opts$fig.alt = 'character'
   opts$fig.dim = 'list'
   opts$R.options = 'list'
   opts$cache.comments = 'logical'
@@ -164,11 +166,12 @@ set_alias = function(...) {
 #' }
 #' @include hooks-html.R
 opts_knit = new_defaults(list(
-  progress = TRUE, verbose = FALSE, eval.after = 'fig.cap',
+  progress = TRUE, verbose = FALSE, eval.after = c('fig.cap', 'fig.alt'),
   base.dir = NULL, base.url = NULL, root.dir = NULL, child.path = '',
   upload.fun = identity, global.device = FALSE, global.par = FALSE,
   concordance = FALSE, documentation = 1L, self.contained = TRUE,
   unnamed.chunk.label = 'unnamed-chunk', highr.opts = NULL,
+  label.prefix = c(table = 'tab:'),
 
   # internal options; users should not touch them
   out.format = NULL, child = FALSE, parent = FALSE, tangle = FALSE, aliases = NULL,
@@ -181,7 +184,7 @@ opts_knit = new_defaults(list(
 opts_knit_names = c(
   'progress', 'verbose', 'upload.fun', 'animation.fun', 'global.device',
   'eval.after', 'concordance', 'documentation', 'aliases', 'self.contained',
-  'unnamed.chunk.label'
+  'unnamed.chunk.label', 'label.prefix'
 )
 # adjust opts_chunk and opts_knit according to options(), e.g.
 # options(knitr.package.progress = FALSE) --> opts_knit$set(progress = FALSE),
