@@ -111,10 +111,10 @@ knit2html = function(input, output = NULL, ..., envir = parent.frame(), text = N
                      quiet = FALSE, encoding = 'UTF-8', force_v1 = FALSE) {
   # packages containing vignettes using R Markdown v1 should declare dependency
   # on 'markdown' in DESCRIPTION (typically in Suggests)
-  if (!is.na(pkg <- check_package_name()) && pkg != 'markdown') {
+  if (!is.na(pkg <- xfun::check_package_name()) && pkg != 'markdown') {
     info = packageDescription(pkg, fields = c('Depends', 'Imports', 'Suggests'))
     if (!'markdown' %in% unlist(strsplit(unlist(info), '[[:space:],]+'))) {
-      if (is_CRAN_incoming()) stop2(
+      if (xfun::is_CRAN_incoming()) stop2(
         "The 'markdown' package should be declared as a dependency of the '", pkg,
         "' package (e.g., in the  'Suggests' field of DESCRIPTION), because it ",
         "contains vignette(s) built with the 'markdown' package. Please see ",
@@ -144,7 +144,10 @@ knit2html_v1 = function(...) knit2html(..., force_v1 = TRUE)
 #' Knit an R Markdown document and post it to WordPress
 #'
 #' This function is a wrapper around the \pkg{RWordPress} package. It compiles
-#' an R Markdown document to HTML and post the results to WordPress.
+#' an R Markdown document to HTML and post the results to WordPress. Please note
+#' that \pkg{RWordPress} has not been updated for several years, which is
+#' \href{https://github.com/yihui/knitr/issues/1866}{not a good sign}. For
+#' blogging with R, you may want to try the \pkg{blogdown} package instead.
 #' @param input Filename of the Rmd document.
 #' @param title Title of the post.
 #' @param ... Other meta information of the post, e.g. \code{categories = c('R',
@@ -154,10 +157,10 @@ knit2html_v1 = function(...) knit2html(..., force_v1 = TRUE)
 #'   for syntax highlighting of source code and output. The first element
 #'   applies to source code, and the second applies to text output. By default,
 #'   both are \code{FALSE}.
-#' @param action Whether to create a new post, update an existing post, or create a new
-#'   page.
-#' @param postid If \code{action} is \code{editPost}, the post id \code{postid} must be
-#'   specified.
+#' @param action Whether to create a new post, update an existing post, or
+#'   create a new page.
+#' @param postid If \code{action} is \code{editPost}, the post id \code{postid}
+#'   must be specified.
 #' @param publish Boolean: publish the post immediately?
 #' @inheritParams knit
 #' @export
@@ -173,6 +176,14 @@ knit2wp = function(
   input, title = 'A post from knitr', ..., envir = parent.frame(), shortcode = FALSE,
   action = c('newPost', 'editPost', 'newPage'), postid, publish = TRUE
 ) {
+  do.call('library', list(package = 'RWordPress', character.only = TRUE))
+  xfun::do_once(
+    warning2(
+      'This function is based on the RWordPress package, which is no longer actively ',
+      'maintained (https://github.com/yihui/knitr/issues/1866). For blogging with R, ',
+      'you may try the blogdown package instead.'
+    ), 'knitr.knit2wp.warning'
+  )
   out = knit(input, envir = envir); on.exit(unlink(out))
   content = file_string(out)
   content = markdown::markdownToHTML(text = content, fragment.only = TRUE)
@@ -203,7 +214,6 @@ knit2wp = function(
   # if we are editing the post, also include the argument for postid
   if (action == "editPost") WPargs = c(postid = postid, WPargs)
 
-  do.call('library', list(package = 'RWordPress', character.only = TRUE))
   do.call(action, args = WPargs)
 }
 
